# Paramenters for installing and configuring RKHunter
class rkhunter::params
{
  $rotate_mirrors  = '1'
  $update_mirrors    = '1'
  $mirrors_mode    = '0'
  $mail_on_warning  = ''
  $tmpdir      = $::osfamily ?
  {
    default    => '/var/lib/rkhunter/tmp',
    'RedHat'  => '/var/lib/rkhunter',
  }

  $dbdir      = '/var/lib/rkhunter/db'
  $scriptdir    = '/usr/share/rkhunter/scripts'
  $logfile    = $::osfamily ?
  {
    default    => '/var/log/rkhunter.log',
    'RedHat'  => '/var/log/rkhunter/rkhunter.log',
  }

  $append_log    = $::osfamily ?
  {
    default    => '0',
    'RedHat'  => '1',
  }

  $copy_log_on_error  = '0'
  $use_syslog    = $::osfamily ?
  {
    default    => undef,
    'RedHat'  => 'authpriv.notice',
  }

  $color_set2    = '0'
  $auto_x_detect    = $::osfamily ?
  {
    default    => '0',
    'RedHat'  => '1',
  }

  $whitelisted_is_white  = '0'
  $allow_ssh_root_user = $::osfamily ?
  {
    default    => 'no',
    'RedHat'  => 'unset',
  }

  $allow_ssh_prot_v1  = '0'
  $enable_tests    = 'all'
  $disable_tests    = 'suspscan hidden_procs deleted_files packet_cap_apps apps'
  $immutable_set    = '0'
  $allow_syslog_remote_log  = '0'
  $suspscan_temp    = '/dev/shm'
  $suspscan_maxsize  = '10240000'
  $suspscan_thresh  = '200'
  $use_locking    = '0'
  $lock_timeout    = '300'
  $show_lockmsgs    = '1'
  $disable_unhide    = $::osfamily ?
  {
    default  => '1',
    'RedHat' => '0',
  }

  $installdir    = '/usr'
  $ssh_config_dir    = undef    # "/etc/ssh"
  $hash_func    = undef    # "sha1sum"
  $hash_fld_idx    = undef    # "4"
  $package_manager  = $::osfamily ?
  {
    default  => undef,  # "NONE"
    'RedHat' => 'RPM',
  }

  $pkgmgr_no_verfy = [] # ['/etc/fooconfig1', '/etc/foobarconfig']
  $ignore_prelink_dep_err  = []    # ['/bin/ps /usr/bin/top', '/bin/foobin']
  $use_sunsum    = undef    # "0"
  $existwhitelist    = $::osfamily ?
  {
    default  => [],
    'RedHat' =>
    [
      '/var/log/pki-ca/system',
      '/var/log/pki/pki-tomcat/ca/system',
      '/usr/bin/GET',
      '/usr/bin/whatis',
    ],
  }
  $attrwhitelist    = []
  $writewhitelist    = []
  $scan_mode_dev    = undef
  $phlanx2_dirtest  = '0'
  $inetd_conf_path  = undef
  $inetd_allowed_svc  = []    # ['echo']
  $xinetd_conf_path  = undef    # "/etc/xinetd.conf"
  $xinetd_allowed_svc  = []    # ['echo']
  $startup_paths    = []    # ['/etc/init.d /etc/rc.local']
  $passwd_file    = undef    # "/etc/shadow"
  $user_fileprop_files_dirs  = [] # ['top /usr/local/sbin !/opt/ps*', 'file']
  $rtkt_file_whitelist = $::osfamily ?
  {
    default  => ['/var/log/pki-ca/system', '/var/log/pki/pki-tomcat/ca/system',],
    'RedHat' =>
    [
      '/var/log/pki-ca/system',
      '/var/log/pki/pki-tomcat/ca/system',
    ],
  }

  $rtkt_dir_whitelist  = []
  $os_version_file  = undef    # "/etc/debian_version"
  $stat_cmd    = undef    # "BUILTIN"
  $readlink_cmd    = undef    # "BUILTIN"
  $web_cmd    = undef    #
  $warn_on_os_change  = undef    # "1"
  $updt_on_os_change  = undef    # "0"
  $scanrootkitmode  = undef    # "TROUGH"
  $unhide_tests    = undef    # "sys"
  $scriptwhitelist  = $::osfamily ?
  {
    default    =>
    [
      '/bin/egrep',
      '/bin/fgrep',
      '/bin/which',
      '/usr/bin/groups',
      '/usr/bin/ldd',
      '/usr/bin/lwp-request',
      '/usr/sbin/adduser',
      '/usr/sbin/prelink',
    ],
    'RedHat'  =>
    [
      '/usr/bin/whatis',
      '/usr/bin/ldd',
      '/usr/bin/groups',
      '/usr/bin/GET',
      '/sbin/ifup',
      '/sbin/ifdown',
    ],
  }

  $immutewhitelist  =
  [
    # '/sbin/ifup /sbin/ifdown',
  ]

  $allowhiddendir = $::osfamily ?
  {
    default    =>
    [
      # '/etc/.java',
      # '/dev/.static',
      # '/dev/.SRC-unix',
      # '/etc/.etckeeper',
    ],
    'RedHat'  =>
    [
      '/etc/.java',
      '/dev/.udev',
      '/dev/.udevdb',
      '/dev/.udev.tdb',
      '/dev/.udev/db',
      '/dev/.udev/rules.d',
      '/dev/.static',
      '/dev/.initramfs',
      '/dev/.SRC-unix',
      '/dev/.mdadm',
      '/dev/.systemd',
      '/dev/.mount',
      '/etc/.git',
      '/etc/.bzr',
    ],
    'Debian'  =>
    [
      '/etc/.java',
      '/dev/.udev',
      '/dev/.initramfs',
    ],

  }
  $allowhiddenfile = $::osfamily ?
  {
    default    =>
    [
      # '/etc/.bzrignore',
    ],
    'RedHat'  =>
    [
      '/usr/share/man/man1/..1.gz',
      '/lib*/.libcrypto.so.*.hmac',
      '/lib*/.libssl.so.*.hmac',
      '/usr/bin/.fipscheck.hmac',
      '/usr/bin/.ssh.hmac',
      '/usr/bin/.ssh-keygen.hmac',
      '/usr/bin/.ssh-keyscan.hmac',
      '/usr/bin/.ssh-add.hmac',
      '/usr/bin/.ssh-agent.hmac',
      '/usr/lib*/.libfipscheck.so.*.hmac',
      '/usr/lib*/.libgcrypt.so.*.hmac',
      '/usr/lib*/hmaccalc/sha1hmac.hmac',
      '/usr/lib*/hmaccalc/sha256hmac.hmac',
      '/usr/lib*/hmaccalc/sha384hmac.hmac',
      '/usr/lib*/hmaccalc/sha512hmac.hmac',
      '/usr/sbin/.sshd.hmac',
      '/dev/.mdadm.map',
      '/dev/.udev/queue.bin',
      '/usr/share/man/man5/.k5login.5.gz',
      '/usr/share/man/man5/.k5identity.5.gz',
      '/usr/sbin/.ipsec.hmac',
      '/sbin/.cryptsetup.hmac',
      '/etc/.etckeeper',
      '/etc/.gitignore',
      '/etc/.bzrignore',
    ],
  }
  $allowprocdelfile   =
  [
    # '/sbin/cardmgr /usr/sbin/gpm:/etc/X11/abc',
    # '/usr/lib/libgconf2-4/gconfd-2',
    # '/usr/sbin/mysqld:/tmp/ib*',
    # '/usr/lib/iceweasel/firefox-bin',
    # '/usr/bin/file-roller',
  ]

  $allowproclisten   =
  [
    # '/sbin/dhclient /usr/bin/dhcpcd',
    # '/usr/sbin/pppoe /usr/sbin/tcpdump',
    # '/usr/sbin/snort-plain',
  ]

  $allowpromiscif   =
  [
    # 'eth0',
  ]

  $allowdevfile    = $::osfamily ?
  {
    default    =>
    [
      # '/dev/shm/pulse-shm-*',
      # '/dev/shm/sem.ADBE_*',
    ],
    'RedHat'  =>
    [
      '/dev/shm/pulse-shm-*',
      '/dev/md/md-device-map',
      '/dev/shm/mono.*',    # tomboy creates this one
      '/dev/shm/libv4l-*',    # created by libv4l
      '/dev/shm/spice.*',    # created by spice video
      '/dev/.mdadm.map',
      '/dev/.udev/queue.bin',
      '/dev/.udev/db/*',
      '/dev/.udev/rules.d/99-root.rules',
      '/dev/.udev/uevent_seqnum',
      '/dev/md/autorebuild.pid',  # created by mdadm
      '/dev/shm/sem.slapd-*.stats',  # 389 Directory Server
    ],
  }

  $uid0_accounts    =
  [
    # 'toor rooty sashroot',
  ]

  $pwdless_accounts  =
  [
    # 'someuser',
  ]

  $syslog_config_file  =
  [
    # '/etc/syslog.conf',
  ]

  $app_whitelist    =
  [
    # 'openssl:0.9.7d gpg httpd:1.3.29',
  ]

  $suspscan_dirs    =
  [
    # '/tmp /var/tmp',
  ]

  $port_whitelist    =
  [
    # '/home/user1/abc /opt/xyz TCP:2001 UDP:32011',
  ]

  $shared_lib_whitelist  =
  [
    # '/lib/snoopy.so',
  ]

  case $::osfamily
  {
    default:
    {
      $package_name  = 'rkhunter'
    }
    'Debian':
    {
      $package_name  = 'rkhunter'
    }
    'RedHat':
    {
      $package_name  = 'rkhunter'
    }
    'FreeBSD':
    {
      $package_name  = 'security/rkhunter'
    }
  }
}
